#' 99100 Blank, Type Of Solution, Fixed Value Code
#'
#' A table containing the USGS Blank, Type Of Solution, Fixed Value Code
#' parameter codes.
#'
#' @format A data frame with 13 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_99100"
#> [1] "pmcode_99100"
